==> 0q0-roblox-1.4.6.tgz: package/lib/catalog/onAssetUpdate.js <==
// Includes
var shortPoll = require('../util/shortPoll.js').func;
var searchCatalog = require('./searchCatalog.js').func;
var resolveDate = require('../util/resolveDate.js').func;

// Args
exports.required = [];
exports.optional = ['geartype', 'genre', 'category', 'subcategory', 'currency', 'sort', 'freq', 'keyword', 'creatorID', 'minim', 'maxim', 'notforsale', 'pagenumber', 'resultsperpage'];

// Define
exports.func = function (args) {
  var geartype = args.geartype;
  var genre = args.genre;
  var category = args.category;
  var subcategory = args.subcategory;
  var currency = args.currency;
  var freq = args.freq;
  var keyword = args.keyword;
  var creatorID = args.creatorID;
  var minim = args.minim;
  var maxim = args.maxim;
  var notforsale = args.notforsale;
  var pagenumber = args.pagenumber;
  var resultsperpage = args.resultsperpage;
  return shortPoll({
    getLatest: function (latest) {
      return searchCatalog({geartype: geartype, genre: genre, category: category, subcategory: subcategory, currency: currency, sort: 3, keyword: keyword, creatorID: creatorID, minim: minim, maxim: maxim, notforsale: notforsale, pagenumber: pagenumber, resultsperpage: resultsperpage})
      .then(function (assets) {
        var given = [];
        for (var i = assets.length - 1; i >= 0; i--) {
          var asset = assets[i];
          var id = resolveDate({date: asset.UpdatedDate});
          if (id > latest) {
            latest = id;
            given.push(asset);
          }
        }
        return {
          latest: latest,
          data: given
        }
      }).catch(function() {
        return {
          latest: latest,
          data: []
        }
      });
    },
    delay: 'onAssetUpdate',
    timeout: -1
  });
};

==> 0q0-roblox-1.5.6.tgz: package/lib/catalog/onAssetUpdate.js <==
var shortPoll = require('../util/shortPoll.js').func;
var searchCatalog = require('./searchCatalog.js').func;
var resolveDate = require('../util/resolveDate.js').func;

exports.required = [];
exports.optional = ['geartype', 'genre', 'category', 'subcategory', 'currency', 'sort', 'freq', 'keyword', 'creatorID', 'minim', 'maxim', 'notforsale', 'pagenumber', 'resultsperpage'];

exports.func = function (args) {
  var geartype = args.geartype;
  var genre = args.genre;
  var category = args.category;
  var subcategory = args.subcategory;
  var currency = args.currency;
  var freq = args.freq;
  var keyword = args.keyword;
  var creatorID = args.creatorID;
  var minim = args.minim;
  var maxim = args.maxim;
  var notforsale = args.notforsale;
  var pagenumber = args.pagenumber;
  var resultsperpage = args.resultsperpage;
  return shortPoll({
    getLatest: function (latest) {
      return searchCatalog({geartype: geartype, genre: genre, category: category, subcategory: subcategory, currency: currency, sort: 3, keyword: keyword, creatorID: creatorID, minim: minim, maxim: maxim, notforsale: notforsale, pagenumber: pagenumber, resultsperpage: resultsperpage})
      .then(function (assets) {
        var given = [];
        for (let i = assets.length - 1; i >= 0; i--) {
          let asset = assets[i];
          let id = resolveDate({date: asset.UpdatedDate});
          if (id > latest) {
            latest = id;
            given.push(asset);
          }
        }
        return {
          latest: latest,
          data: given
        }
      });
    },
    delay: 'onAssetUpdate',
    timeout: -1
  });
};
